@@ -22,27 +22,29 @@ static int init_vsl(int argc, char **argv)
 	int c;
 	struct VSM_data *vd;
 
-	vd = VSM_New();
-	VSL_Setup(vd);
+	if (m_vd != NULL)
+	{
+		VSM_ReOpen(m_vd, 0);
+	}
+	else
+	{
+		m_vd = VSM_New();
+	}
+
+	VSL_Setup(m_vd);
 
 	while ((c = getopt(argc, argv, VSL_ARGS)) != -1)
 	{
-		VSL_Arg(vd, c, optarg);
+		VSL_Arg(m_vd, c, optarg);
 	}
 
-	if (VSL_Open(vd, 1))
+	if (VSL_Open(m_vd, 1))
 	{
 		return -1;
 	}
 
-	VSL_NonBlocking(vd, 1);
+	VSL_NonBlocking(m_vd, 1);
 
-	if (m_vd != NULL)
-	{
-		VSM_Delete(m_vd);
-	}
-
-	m_vd = vd;
 	return 0;
 }
 
